@@ -187,6 +187,7 @@ class ArgumentParser(argparse.ArgumentParser):
         group.add_argument('-D', '--debug', dest='debug', action='store_true', default=False, help='''don't delete intermediate files''')
         group.add_argument('-X', dest='properties', metavar='KEY=VALUE', help='set an engine-specific property', action='append', default=[])
         group.add_argument('--on-error', choices=('abort', 'resume'), default='abort', help='error handling strategy')
+        group.add_argument('--html5', dest='html5', action='store_true', help='use HTML5 parse')
 
     class set_engine(argparse.Action):
         def __call__(self, parser, namespace, values, option_string=None):
@@ -338,6 +339,7 @@ class Context(djvu.decode.Context):
                         rotation=page.rotation,
                         details=self._options.details,
                         uax29=self._options.uax29,
+                        html5=self._options.html5,
                         page_size=size
                     )
                     # It should be: (page 0 0 <width> <height> …):
