@@ -1,23 +1,24 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+
+# Copyright © 2008, 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
+# This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; version 2 dated June, 1991.
 #
-# This package is distributed in the hope that it will be useful, but
+# This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
+import logging
 import os
 import re
 import signal
 import subprocess
 
-PIPE = subprocess.PIPE
-
-from subprocess import CalledProcessError
+# CalledProcessError, CalledProcessInterrupted
+# ============================================
 
 # Protect from scanadf[0] and possibly other brain-dead software that set
 # SIGCHLD to SIG_IGN.
@@ -44,6 +45,8 @@ def get_signal_names():
         pass
     return dict((no, name) for name, no in data.iteritems())
 
+CalledProcessError = subprocess.CalledProcessError
+
 class CalledProcessInterrupted(CalledProcessError):
 
     _signal_names = get_signal_names()
@@ -58,6 +61,14 @@ class CalledProcessInterrupted(CalledProcessError):
 
 del get_signal_names
 
+# Subprocess
+# ==========
+
+def shell_escape(s, safe=re.compile('^[a-zA-Z0-9_+/=.,:%-]+$').match):
+    if safe(s):
+        return s
+    return "'%s'" % s.replace("'", r"'\''")
+
 class Subprocess(subprocess.Popen):
 
     @classmethod
@@ -83,9 +94,12 @@ class Subprocess(subprocess.Popen):
         if os.name == 'posix':
             kwargs.update(close_fds=True)
         try:
-            self.__command = kwargs['args'][0]
+            commandline = kwargs['args']
         except KeyError:
-            self.__command = args[0][0]
+            commandline = args[0]
+        if logger.isEnabledFor(logging.DEBUG):
+            logger.debug(' '.join(shell_escape(s) for s in commandline))
+        self.__command = commandline[0]
         subprocess.Popen.__init__(self, *args, **kwargs)
 
     def wait(self):
@@ -95,4 +109,22 @@ class Subprocess(subprocess.Popen):
         if return_code < 0:
             raise CalledProcessInterrupted(-return_code, self.__command)
 
+# PIPE
+# ====
+
+PIPE = subprocess.PIPE
+
+# logging support
+# ===============
+
+logger = logging.getLogger('ocrodjvu.ipc')
+
+# __all__
+# =======
+
+__all__ = [
+    'CalledProcessError', 'CalledProcessInterrupted',
+    'Subprocess', 'PIPE',
+]
+
 # vim:ts=4 sw=4 et
