@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -82,13 +82,15 @@ except AttributeError:
     @contextlib.contextmanager
     def catch_warnings():
         original_filters = warnings.filters
+        original_show = warnings.showwarning
         try:
             yield
         finally:
             warnings.filters = original_filters
+            warnings.showwarning = original_show
 
 @contextlib.contextmanager
-def raises(exc_type, string=None, regex=None, callback=None):
+def exception(exc_type, string=None, regex=None, callback=None):
     if sum(x is not None for x in (string, regex, callback)) != 1:
         raise ValueError('exactly one of: string, regex, callback must be provided')
     if string is not None:
@@ -118,7 +120,7 @@ __all__ = list(__all__) + [
     'amended_environment',
     'try_run',
     'catch_warnings',
-    'raises',
+    'exception',
     'sorted_glob',
 ]
 
